"use strict";

/* eslint-disable no-underscore-dangle */
var chai = require('chai');

var chaiAsPromised = require('chai-as-promised');

var _require = require('./FileReaders'),
    LocalFileReader = _require.LocalFileReader;

var TabixIndexedFile = require('./TabixIndexedFile');

chai.use(chaiAsPromised);
var expect = chai.expect;
describe('TabixIndexedFile', function () {
  function getTestFile() {
    var vcfPath = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : './test-data/single_sample.vcf.gz';
    var idxPath = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : "".concat(vcfPath, ".tbi");
    return new TabixIndexedFile(new LocalFileReader(vcfPath), new LocalFileReader(idxPath));
  }

  it('should load tabix index', function () {
    var indexedFile = getTestFile();
    return indexedFile._contigs.then(function (contigs) {
      expect(contigs.size).to.equal(1);
    });
  });
  it('should reject on invalid index file', function () {
    var indexedFile = getTestFile('./test-data/single_sample.vcf.gz', './test-data/single_sample.vcf.gz');
    return expect(indexedFile._contigs).to.be.rejected;
  });
  it('should return requested records', function () {
    var indexedFile = getTestFile();
    return indexedFile.records('chr1', 1, 200).then(function (records) {
      expect(records).to.deep.equal(['chr1\t100\trs1\tA\tT\t100.0\tPASS\tAC=1;AN=2\tGT\t0/1']);
    });
  });
  it('should return zero length array for empty region', function () {
    var indexedFile = getTestFile();
    return indexedFile.records('chr1', 102, 102).then(function (records) {
      expect(records).to.have.lengthOf(0);
    });
  }); // TODO: Test filtering on structural variants

  it('should return header lines', function () {
    var indexedFile = getTestFile();
    return indexedFile.header().then(function (header) {
      expect(header).to.have.lengthOf(7);
    });
  });
});